/**
 *  Copyright (c) 2014, 
 *  BTC Embedded Systems AG, Oldenburg, Germany  
 *  All rights reserved
 *  --------------------------------------------------------- 
 *  $Author: $
 *  $Date:  $
 *  $Revision: $
 **/

package com.btc.ep.dal.persist;

import java.io.File;

import com.btc.ep.dal.persist.impl.PersistenceService;

/**
 * Access data model
 * 
 * @author jacek
 * 
 */
public abstract class PersistenceManager {

    /**
     * get PersistenceService singleton
     * 
     * @return The PersistenceService
     */
    public abstract PersistenceService getPersistenceService();

    /**
     * Backup the data to given file
     *
     * @param backupFile the backup target file
     * @throws Exception If the file can't access. (e.g. File does not exist.)
     */
    public abstract void backup(File backupFile) throws Exception;

    /**
     * clear (i.e. remove) data files; stopping or calling open() are the only options after this
     *
     */
    public abstract void clear();

    /**
     * Closes the DB connection; you can reopen it by calling {@link #getPersistenceService()}
     *
     */
    public abstract void close();

    /**
     * restore (open) data from given file; call {@link #getPersistenceService()} to connect.
     *
     * @param path Path to the file to open
     * @throws Exception If the file can't access. (e.g. File does not exist.) 
     */
    public abstract void open(File path) throws Exception;

}
