/**
 *  Copyright (c) 2014, 
 *  BTC Embedded Systems AG, Oldenburg, Germany  
 *  All rights reserved
 *  --------------------------------------------------------- 
 *  $Author: $
 *  $Date:  $
 *  $Revision: $
 **/

package com.btc.ep.dal.provider;

import java.io.File;

import javax.persistence.EntityManagerFactory;

// ---------------------------------------------------------------------------
// Implementation
// ---------------------------------------------------------------------------

/**
 * Provider for PersistenceManager
 * 
 * @author jacek
 * @author Simon Kollmann
 */
public interface PersistenceManagerProvider {

    /**
     * gets an ID for this provider
     *
     * @return Id for this provider
     */
    String getId();

    /**
     * connects to the database
     *
     * @return a EntityManagerFactory
     */
    EntityManagerFactory getEntityManagerFactory();

    /**
     * gets the path to the DB file(s)
     *
     * @return path to the DB file
     */
    File getDBPath();

    /**
     * create a backup of the Database
     *
     * @param backupFile destination file for the bakcup
     * @throws Exception If the file can't access. (e.g. File does not exist.)
     */
    void backup(File backupFile) throws Exception;

    /**
     * close the connection
     *
     */
    void close();

    /**
     * effectively purge database files from disk
     *
     */
    void clearFiles();

    /**
     * restore database files from given file
     *
     * @param path Path to the given database file
     * @throws Exception If the file can't access. (e.g. File does not exist.) 
     */
    void openFile(File path) throws Exception;

}

// ---------------------------------------------------------------------------
// END OF FILE
// ---------------------------------------------------------------------------
