/**
 *  Copyright (c) 2014, 
 *  BTC Embedded Systems AG, Oldenburg, Germany  
 *  All rights reserved
 *  --------------------------------------------------------- 
 *  $Author: $
 *  $Date:  $
 *  $Revision: $
 **/

package com.btc.ep.domainThree.dal.tests.it;

import java.util.concurrent.atomic.AtomicInteger;

import com.btc.ep.core.Services;
import com.btc.ep.dal.persist.PersistenceManager;
import com.btc.ep.dal.persist.impl.PersistenceService;

/**
 * This class is the base of the unit test.
 * And offers complicated methods to create DTO objects in DAL tests.
 * 
 * @author Martin Manthey
 */
public class BaseTest {

    /**
     * PersistenceContext uses by all unit tests
     */
    private static PersistenceService persistenceService;

    protected long startTime;

    protected AtomicInteger counter = new AtomicInteger(1);

    /**
     * deletes all entities in the database
     */
    protected void deleteDatabase() {
        getPersistenceService().updateQuery("DELETE FROM Object"); // delete whole database
    }

    /**
     * Returns the persistence context.
     * 
     * @return the persistence context
     */
    public PersistenceService getPersistenceService() {
        if (persistenceService == null) {
            PersistenceManager persistenceManager = Services.get(PersistenceManager.class);
            persistenceService = persistenceManager.getPersistenceService();
        }
        return persistenceService;
    }

    /**
     * destroys persistence service
     */
    public static void destroyPersistenceService() {
        PersistenceManager persistenceManager = Services.get(PersistenceManager.class);
        persistenceService = null;
        persistenceManager.close();
    }

    /**
     * converts bytes in mb
     * 
     * @param value bytes
     * @return value in mb
     */
    private String convertMemory(long value) {
        return "" + value / 1024 / 1000 + "MB";
    }

    /**
     * prints memory info to the console
     */
    public void memoryInfo() {

        long max = Runtime.getRuntime().maxMemory();
        long free = Runtime.getRuntime().freeMemory();
        long total = Runtime.getRuntime().totalMemory();

        System.out.println("max: " + convertMemory(max));
        System.out.println("free: " + convertMemory(free));
        System.out.println("total: " + convertMemory(total));
        System.out.println("used: " + convertMemory((total - free)));
        System.out.println("");
    }

    /**
     * remarks the time at now
     */
    public void remarkTime() {
        startTime = System.currentTimeMillis();
    }

    /**
     * Call this after call remarkTime().
     * Prints the used time until now to the console.
     *
     * @param usecase description of used time
     * @see BaseTest#remarkTime()
     */
    public void printTime(String usecase) {
        System.out.println(usecase + " time: " + (System.currentTimeMillis() - startTime));
    } 

}
